@@ -18,14 +18,18 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 
 import argparse
+import glob
 import httplib
 import os
+import pickle
 import pwd
 import re
 import sys
+import tarfile
 import urllib
 import warnings
 import xmlrpclib
+import zipfile
 
 from datetime import datetime
 from pprint import pprint
@@ -33,7 +37,7 @@ from pprint import pprint
 warnings.filterwarnings('ignore', 'Module argparse was already imported')   # Filter a UserWarning from Jinja2
 import jinja2
 
-__version__ = '0.4.1'
+__version__ = '0.4.3'
 
 
 class ProxiedTransport(xmlrpclib.Transport):
@@ -49,11 +53,13 @@ class ProxiedTransport(xmlrpclib.Transport):
         connection.putheader('Host', self.realhost)
 
 
-
 TEMPLATE_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'templates')  # absolute template path
 pypi = xmlrpclib.ServerProxy('http://python.org/pypi')                      # XML RPC connection to PyPI
 env = jinja2.Environment(loader=jinja2.FileSystemLoader(TEMPLATE_DIR))      # Jinja2 template environment
 
+SPDX_LICENSES_FILE = 'py2pack/suse_spdx_license_map.p'
+SDPX_LICENSES = pickle.load(open(SPDX_LICENSES_FILE, 'rb'))
+
 
 def list(args):
     print('listing all PyPI packages...')
@@ -85,6 +91,37 @@ def fetch(args):
     urllib.urlretrieve(url['url'], url['filename'])                         # download the object behind the URL
 
 
+def _augment_data_from_tarball(args, filename, data):
+    setup_filename = "{0}-{1}/setup.py".format(args.name, args.version)
+    docs_re = re.compile("{0}-{1}\/(AUTHOR|CHANGES|COPYING|LICENSE|NEWS|README(?:\.\w+)?)".format(args.name, args.version), re.IGNORECASE)
+
+    if tarfile.is_tarfile(filename):
+        with tarfile.open(filename) as f:
+            for line in f.extractfile(setup_filename):
+                if "ext_modules" in line:                                   # tarball contains C/C++ extension
+                    data["is_extension"] = True
+            for name in f.getnames():
+                match = re.match(docs_re, name)
+                if match:
+                    print "DOC", match.groups()
+                    if not "doc_files" in data:
+                        data["doc_files"] = []
+                    data["doc_files"].append(match.group(1))
+    elif zipfile.is_zipfile(filename):
+        with zipfile.ZipFile(filename) as f:
+            with f.open(setup_filename) as s:
+                for line in s:
+                    if "ext_modules" in line:                               # tarball contains C/C++ extension
+                        data["is_extension"] = True
+            for name in f.namelist():
+                match = re.match(docs_re, name)
+                if match:
+                    print "DOC", match.groups()
+                    if not "doc_files" in data:
+                        data["doc_files"] = []
+                    data["doc_files"].append(match.group(1))
+
+
 def generate(args):
     check_or_set_version(args)
     if not args.template:
@@ -101,6 +138,15 @@ def generate(args):
     data['year'] = datetime.now().year                                      # set current year
     data['user_name'] = pwd.getpwuid(os.getuid())[4]                        # set system user (packager)
     data['summary_no_ending_dot'] = re.sub('(.*)\.', '\g<1>', data['summary'])
+
+    tarball_file = glob.glob("{0}-{1}*".format(args.name, args.version))    # we have a local tarball, try to 
+    if tarball_file:                                                        # get some more info from that
+        _augment_data_from_tarball(args, tarball_file[0], data)
+
+
+    if data['license'] in SDPX_LICENSES:                                    # if we have a mapping, transform 
+        data['license'] = SDPX_LICENSES[data['license']]                    # license into SPDX style
+
     template = env.get_template(args.template)
     result = template.render(data).encode('utf-8')                          # render template and encode properly
     outfile = open(args.filename, 'w')                                      # write result to spec file
